<?php

namespace Teknisa\CADCTB\Services;

use Zeedhi\Framework\DTO\Response;
use Teknisa\Libs\Util\DateUtil;
use Zeedhi\Framework\DataSource\DataSet;
use Doctrine\ORM\EntityManager;
use Teknisa\Libs\Util\Environment;
use Zeedhi\Framework\DB\StoredProcedure\Param;
use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;

class Ger17300InformativoComposicaoCustosService{

    protected $environment;
    protected $nrorg;
    
    
    public function __construct(EntityManager $entityManager, Environment $environment) {
        $this->environment = $environment;
        $this->entityManager = $entityManager;
        $this->nrorg = $environment->getNrOrgTrab();
        $this->connection = $entityManager->getConnection();
    }

    
    public function salvarImportacaoL210($row){
        try{
            $this->deleteREGL210ECF();
    
            $file = $this->decodeFile($row['UPLOADFILE'][0]["b64File"]);
            $fileLines = $this->returnStringInlines($file);
            foreach ($fileLines as $lineNumber => $line) {
                if($lineNumber >0 && $line != ''){
                    // a os atributos são separados por | na linha 
                    $line = explode('|', $line);
                    $receitaItem = [];
                    $receitaItem['NRSEQREGL210']  = $line[0];
                    $receitaItem['CDREGL210']     = $line[4];
                    $receitaItem['DSREGL210']     = $line[1];
                    $receitaItem['DTINI']         = $line[2];
                    $receitaItem['DTFIM']         = $line[3];
                    $receitaItem['IDTIPOL210']    = $line[5];
                    $receitaItem['DSFORMULA']     = $line[8];
                    
                    $this->salvarREGL210ECF($receitaItem);
                }
            }
        }    
        catch (\Exception $e) {
            throw (new \Exception("Erro ao ler arquivo : ". $e->getMessage(), 500));
        }
    }
    /**
     * Essa função tem como finalidade receber uma string que contém quebras de linhas,
     * e retornar em um array as linhas, onde cada posição do array contém uma linha da
     * string lida.
     *
     * @param $file | string completa com quebras de linha
     *
     * @return $file | array de strings, onde cada posição é uma linha
     */
    public function returnStringInlines($file) {
        $file = preg_split('/\R/', $file);
        return $file;
    }
    /**
     * Essa função tem como finalidade receber uma string codificada em base 64 e
     * descidificala para ser usada nas funções dessa classe.
     *
     * @param  string $encodedFile codificada em base64
     * @return string              decodificada
     */
    public function decodeFile($encodedFile) {
        $file = utf8_encode(base64_decode($encodedFile));
        return $file;
    }
    
    public function deleteREGL210ECF(){
        try{
            // Query a ser executada.
            $sql = "DELETE FROM REGL210ECF";
    
            // Prepara o statement da query para execução.
            $statement = $this->connection->prepare($sql);
            
            // Executa o statement com os paràmetros passados.
            $statement->execute();
            
        }
        catch (\Exception $e) {
            throw $e;
        }
    }
    
        
    public function salvarREGL210ECF($row){
      
        $sql = "INSERT INTO REGL210ECF
               (NRSEQREGL210, CDREGL210, DSREGL210, DTINI,
                DTFIM, IDTIPOL210, DSFORMULA, NRORG)
                VALUES
               (:NRSEQREGL210, :CDREGL210, :DSREGL210, :DTINI,
                :DTFIM, :IDTIPOL210, :DSFORMULA, :NRORG)";
                
        $params = array(
            'NRSEQREGL210'=>$row['NRSEQREGL210'],
            'CDREGL210'=>$row['CDREGL210'],
            'DSREGL210'=>$row['DSREGL210'],
            'DTINI'=>$row['DTINI'],
            'DTFIM'=>$row['DTFIM'],
            'IDTIPOL210'=>$row['IDTIPOL210'],
            'DSFORMULA'=> $row['DSFORMULA'],
            'NRORG'=>$this->nrorg
        );
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        
    }
    
    
}